@@ -42,6 +42,16 @@ impl Indexer {
         }
     }
 
+    /// Check if indexer contains table
+    pub fn contains_table(&self, table_name: &str) -> bool {
+        self.tables.contains_key(table_name)
+    }
+
+    /// Drop table
+    pub fn drop_table(&mut self, table_name: &str) {
+        self.tables.remove(table_name);
+    }
+
     /// Add table without header
     pub fn add_table_fast(&mut self, table_name: &str, input: impl Read) -> CIndexResult<()>{
         self.add_table(table_name, vec![], input)
@@ -69,14 +79,14 @@ impl Indexer {
 
             headers = header_types_iter.zip(header_lines_iter).take(len).map(|(value,t)| (t.to_owned(), *value)).collect();
         } else {
-            panic!("No header option is not supported");
+            return Err(CIndexError::InvalidTableInput(format!("No header option is not supported")));
         }
 
         for line in lines {
             let row: Vec<&str> = line.split(',').collect();
 
             if row.len() != headers.len() {
-                panic!("Row's length is different from header's length ");
+                return Err(CIndexError::InvalidTableInput(format!("Row's length \"{}\" is different from header's length \"{}\"", row.len(), headers.len())));
             }
 
             rows.push(row);
